@@ -805,14 +805,14 @@ def get_parameter_dict(nb_fname):
                 #real_value = gettype(inferred_type)(value)
             else:
                 real_value = json.loads(value)
-            print(value, real_value)
+            #print(value, real_value)
             master_nb_parameters.update({kk:real_value})
     return master_nb_parameters
 
 def get_last_file(pattern="*/*.ipynb"):
     # get list of files that matches pattern
 
-    files = list(filter(os.path.isfile, glob(pattern)))
+    files = list(filter(os.path.isfile, glob.glob(pattern)))
     files = list(filter(lambda x :('output' not in x), files))
     # sort by modified time
     files.sort(key=lambda x: os.path.getmtime(x))
@@ -839,6 +839,8 @@ def process_notebook():
 	parser.add_argument("--in_nb", help="Notebook to derive input parameters (to be found in OBSID)", type=str, default='none')
 	parser.add_argument("--in_yaml", help="yaml file with parameters (to be found in OBSID, or relative path)", type=str, default='none')
 	parser.add_argument("--select_nb", help="Select the last nb with pattern ep_??_*", action='store_true')
+	parser.add_argument("--min_sn_matrix", help="Minimum S/N to rebin matrixes", type=float, default=-1)
+	parser.add_argument("--use_nb2workflow", help="If running the notebook as ", action='store_true')	
 
 	if len(sys.argv) == 1:
 		parser.print_help()
@@ -864,11 +866,10 @@ def process_notebook():
 		logger.error("The base notebook you specified does not exist "+base_nb)
 		return 1
 
-	shutil.copy(base_nb, 'notebook_to_run.ipynb')
-
 	p  = re.compile('ep[_-][a-z]{2}[_-]*')
+	p1 = re.compile('Elaboration[_-][0-9]{11}.ipynb')
 
-	local_nb_parameters ={}
+	local_nb_parameters = {}
 
 	if args.select_nb:
 		my_nb = get_last_file('*.ipynb')
@@ -876,7 +877,11 @@ def process_notebook():
 			print(f'Using {my_nb}')
 			local_nb_parameters.update(get_parameter_dict(my_nb))
 		else:
-			print(f'not using {my_nb}')
+			if p1.match(my_nb):
+				print(f'Using {my_nb}')
+				local_nb_parameters.update(get_parameter_dict(my_nb))
+			else:
+				print(f'not using {my_nb}')
 
 	if args.in_nb != 'none':
 		if not os.path.isfile(args.in_nb):
@@ -893,21 +898,34 @@ def process_notebook():
 
 	if args.force_matrix:
 		local_nb_parameters.update({'recompute_matrixes' : True})
+	
+	if args.min_sn_matrix != -1:
+		local_nb_parameters.update({'min_sn_matrix' : args.min_sn_matrix})
 
 	now = datetime.now().strftime("%Y_%m_%d_%H_%M_%S")
-	
 	basename = os.path.basename(base_nb).replace('.ipynb','')
 	output_mosaics_notebook_path = basename+f'_output_{now}.ipynb'
 	print(f'Processing {obsid}')
-	print(base_nb + ' into ' + output_mosaics_notebook_path)
 	print(local_nb_parameters)
-	nb_mosaics_execution = pm.execute_notebook(
-			'notebook_to_run.ipynb',
-			output_mosaics_notebook_path,
-			parameters=local_nb_parameters,
-			log_output=True
-		)
-	os.remove('notebook_to_run.ipynb')
+
+	if args.use_nb2workflow:
+		from nb2workflow import nbadapter
+		shutil.copy(base_nb, output_mosaics_notebook_path)
+		nb_mosaics_execution = nbadapter.nbrun(
+				output_mosaics_notebook_path,
+				local_nb_parameters,
+				inplace=True
+			)
+	else:
+		shutil.copy(base_nb, 'notebook_to_run.ipynb')
+		print(base_nb + ' into ' + output_mosaics_notebook_path)
+		nb_mosaics_execution = pm.execute_notebook(
+				'notebook_to_run.ipynb',
+				output_mosaics_notebook_path,
+				parameters=local_nb_parameters,
+				log_output=True
+			)	
+		os.remove('notebook_to_run.ipynb')
 
 	return nb_mosaics_execution
 	
